from viset.ethzshapes import ETHZShapeClasses
from viset.dataset import Viset
from viset.show import imshow, imbbox

def main():
  dbfile = ETHZShapeClasses().export()
  db = Viset(dbfile, async=False, verbose=True)
  for (im,annotation) in db[0]:
    print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
    imbbox(im,annotation['bbox_xmin'],annotation['bbox_xmax'],annotation['bbox_ymin'],annotation['bbox_ymax'], bboxcaption=annotation['category'])

if __name__ == '__main__':
  main()
        
